pub struct Interaction {
pub id: String,
pub interaction_type: InteractionType,
pub player: String,
pub target: Option<String>,
pub date: Option<NaiveDateTime>,
}Expand description
Interaction between players.
The type of interaction determines the nature of the interaction. It can be a Hunt, Feed, Cure, Corpsify, or any other type of interaction.
Fields
id: Stringinteraction_type: InteractionTypeplayer: Stringtarget: Option<String>date: Option<NaiveDateTime>Implementations
Sourceimpl Interaction
impl Interaction
Sourcepub fn new(
interaction_type: InteractionType,
player: String,
target: Option<String>,
) -> Self
pub fn new( interaction_type: InteractionType, player: String, target: Option<String>, ) -> Self
Creates a new interaction.
Arguments
interaction_type- The type of interaction.player_id- The ID of the player.target_id- The ID of the target player.feed1_id- The ID of the first feed.feed2_id- The ID of the second feed.message- The message of the interaction.
Returns
A new interaction.
Sourcepub async fn save_hunt_interaction(
player: &Player,
target: &Player,
feed1: Option<&Player>,
feed2: Option<&Player>,
) -> Result<(), String>
pub async fn save_hunt_interaction( player: &Player, target: &Player, feed1: Option<&Player>, feed2: Option<&Player>, ) -> Result<(), String>
Save a hunt interaction.
This function saves a hunt interaction between a player and a target. It also saves feed interactions between the player and the target’s feeders.
Arguments
player- The player who initiated the hunt.target- The player who was hunted.feed1- The first feeder of the target.feed2- The second feeder of the target.
Returns
A Result indicating success or failure.
Sourcepub async fn get_newest_interactions() -> Result<Vec<Interaction>, String>
pub async fn get_newest_interactions() -> Result<Vec<Interaction>, String>
This function is used to get the newest interactions:
Returns
A vector of interactions sorted by ID in descending order.
Sourcepub async fn get_all_interactions() -> Result<Vec<InteractionReturnType>, String>
pub async fn get_all_interactions() -> Result<Vec<InteractionReturnType>, String>
This function is used to get all interactions
Z0 is returned as anonymous
Returns
A vector of interactions sorted by ID in descending order.
Sourcepub async fn get_hunt_interactions() -> Result<Vec<Interaction>, String>
pub async fn get_hunt_interactions() -> Result<Vec<Interaction>, String>
Get all interactions related to hunting.
Used in leaderboards and zombie tree
Returns
A vector of hunt interactions
Sourcepub async fn get_leaderboard(
is_zombie: bool,
) -> Result<Vec<LeaderBoardPlayers>, String>
pub async fn get_leaderboard( is_zombie: bool, ) -> Result<Vec<LeaderBoardPlayers>, String>
Get leaderboard data
This represents the zombie list and their kills, ordered by the number of kills, from most to least.
Z0 is returned as anonymous
Returns
A vector of LeaderBoardPlayers, sorted by the number of kills in descending order.
Sourcepub async fn get_zombie_tree() -> Result<(Vec<ZombieTree>, HashMap<String, (PlayerState, PlayerRole)>), String>
pub async fn get_zombie_tree() -> Result<(Vec<ZombieTree>, HashMap<String, (PlayerState, PlayerRole)>), String>